*******************************************************************************
* "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
* Esteban Méndez and Diana Van Patten
*
*******************************************************************************
*Table 5: Students per School and Number of Schools in a Location and Its Outside Option
version 16.1
clear all

set more off

*Path to the folder where dataset is located 
global dirdata "..."

*Path to the final outputs (tables)
global dirout "..."

************ Students per school by census block and outside option ************
use "$dirdata/students_outside_option_dataset.dta", clear

reg log_stud log_outside_option_1973 lat lon slope elevation average_temp area count_people, cluster(segmento)

*Store results
estimates store m_students

****************** School per census block and outside option ******************
use "$dirdata/schools_outside_option_dataset.dta", clear

*Poisson model for number of schools opened within a census block
poisson sch_count log_outside_option_1973 lat lon slope elevation average_temp area count_people, cluster(segmento)

*Store results
estimates store m_schools

*Generate Table 5 using previous results
esttab m_students m_schools using "$dirout/Table_5.tex", cells(b(fmt(3)) se(par fmt(3) star)) ///
star(* 0.1 ** 0.05 *** 0.01) ///
stats(r2_a N, fmt(3 0) label("Adjusted \(R^{2}\)" "Observations")) ///
keep(log_outside_option_1973) ///
varlabels(log_outside_option_1973 "ln Outside Option in 1973") ///
collabels(none) ///
eqlabels(" " " ") ///
mlabels("ln Students per school" "Number of schools per census block") ///
title("Table 5: Students per School and Number of Schools in a Location and Its Outside Option") ///
addnotes("\scriptsize \textit{Notes:} Column (1) shows results using an OLS model on the number of students per school within the UFCo (in logs), while column (2) uses a PPML on the number of schools within the census block. The independent variable is UFCo workers' outside options instrumented with coffee suitability by district. We approximate the number of students with the number of primary school-aged children. Robust standard errors (in parenthesis) clustered by census-block. The regression includes geographic controls (slope, elevation, temperature); the census block area; the number of people living in the census block, and a linear polynomial in latitude and longitude. We denote: \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).") ///
replace