*******************************************************************************
* "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
* Esteban Méndez and Diana Van Patten
*
*******************************************************************************
*Table 6: Schools Opened per Year and Coffee Prices (1899-1984)
version 16.1
clear all

set more off

*Path to the folder where dataset is located 
global dirdata  "..."

*Path to the final outputs (tables)
global dirout "..."

**************************** Prob(Opening a school) ****************************
use "$dirdata/schools_coffee_price.dta", clear

*Probability of open an school
reg open_sch log_coffee_price, cluster( year )

*Store results
estimates store m_prob

*************************** Number of schools opened ***************************
use "$dirdata/schools_coffee_price.dta", clear

*Probability of open an school
nbreg num_sch_open log_coffee_price, cluster( year )

*Store results
estimates store m_numb

*Generate Table 6 using previous results
esttab m_prob m_numb using "$dirout/Table_6.tex", cells(b(fmt(3)) se(par fmt(3) star)) ///
star(* 0.1 ** 0.05 *** 0.01) ///
stats(r2_a N, fmt(3 0) label("Adjusted \(R^{2}\)" "Observations")) ///
keep(log_coffee_price) ///
varlabels(log_coffee_price "ln World Coffee Prices") ///
collabels(none) ///
eqlabels(" " " ") ///
mlabels("Prob(Opening a school)" "Number of schools opened") ///
title("Table 6: Schools Opened per Year and Coffee Prices (1899-1984)") ///
addnotes("\scriptsize \textit{Notes:}   Column (1) shows results using an OLS model on the probability that a school opened within UFCo lands as the dependent variable, while Column (2) uses a negative binomial regression model for the number of schools opened in a given year. Robust standard errors (in parenthesis) clustered by year. We denote: \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).") ///
replace