*******************************************************************************
* "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
* Esteban Méndez and Diana Van Patten
*
*******************************************************************************
*Table D.2: Segments along All the Border where Geographic Characteristics Balance
version 16.1
clear all

set more off

*Path to the folder where dataset is located 
global dirdata "..."

*Path to the ado-file that implements the Conley Standard Errors (ols_spatial_HAC)
global dirado "..."

*Path to the final outputs (tables)
global dirout "..."

*Load the program that implements the Conley Standard Errors (ols_spatial_HAC)
run "$dirado/ols_spatial_HAC.ado" 

* Load dataset
use "$dirdata/geo_balance_charac.dta", clear

foreach distance of num 4 10 {
	
if "`distance'" == "4" {
	local explanation "<4 km of UFCo boundary"
}
if "`distance'" == "10" {
	local explanation "<10 km of UFCo boundary"
}	

	estpost sum elevation slope average_temp if UFCo == 1 & distance<`distance'
	eststo inside_UFCo

	estpost sum elevation slope average_temp if UFCo == 0 & distance<`distance'
	eststo outside_UFCo	

foreach geo_charac in elevation slope average_temp {

	reg `geo_charac' UFCo Turrialba if distance<`distance', r
	
	scalar b_outside_`geo_charac' = _b[_cons]
	
	scalar b_inside_`geo_charac' = _b[_cons] + _b[UFCo]	 

	scalar robust_se_`geo_charac' = _se[UFCo]
	local t = _b[UFCo]/_se[UFCo]
	scalar p_`geo_charac' = 2*ttail(e(df_r),abs(`t'))		

	ols_spatial_HAC `geo_charac' UFCo Turrialba cons if distance<`distance', lat(lat) lon(lon) t(year) p(id) dist(2) lag(0)	
	scalar conley_se_`geo_charac' = _se[UFCo]
	local t = _b[UFCo]/_se[UFCo]
	scalar p_conley_`geo_charac' =2*ttail(e(df_r),abs(`t'))
	
}	
	
	*Store results
	matrix b_inside = (`=b_inside_elevation', ., `=b_inside_slope', ., `=b_inside_average_temp', .)
	mat colnames b_inside = elevation elevation_2 slope slope_2 average_temp average_temp_2
	estadd matrix b_inside: inside_UFCo
	
	matrix b_outside = (`=b_outside_elevation', ., `=b_outside_slope', ., `=b_outside_average_temp', .)
	mat colnames b_outside = elevation elevation_2 slope slope_2 average_temp average_temp_2
	estadd matrix b_outside: outside_UFCo
	
	matrix seval = (`=robust_se_elevation', ., `=robust_se_slope', ., `=robust_se_average_temp', .)
	mat colnames seval = elevation elevation_2 slope slope_2 average_temp average_temp_2
	estadd matrix seval: outside_UFCo
	
	matrix sevalconley = (., `=conley_se_elevation', ., `=conley_se_slope', ., `=conley_se_average_temp')
	mat colnames sevalconley = elevation elevation_2 slope slope_2 average_temp average_temp_2
	estadd matrix sevalconley: outside_UFCo	
	
	matrix pval = (`=p_elevation', ., `=p_slope', ., `=p_average_temp', .)
	mat colnames pval = elevation elevation_2 slope slope_2 average_temp average_temp_2
	estadd matrix pval: outside_UFCo
	
	matrix pvalconley = (., `=p_conley_elevation', ., `=p_conley_slope', ., `=p_conley_average_temp')
	mat colnames pvalconley = elevation elevation_2 slope slope_2 average_temp average_temp_2
	estadd matrix pvalconley: outside_UFCo	

	esttab inside_UFCo outside_UFCo using "$dirout/Table_D2_`distance'.tex", cells("b_inside(pattern(1 0) fmt(3) star) b_outside(pattern(0 1) fmt(3) star) seval(pattern(0 1) par(( )) fmt(3) star pvalue(pval)) sevalconley(pattern(0 1) par([ ]) fmt(3) star pvalue(pvalconley))") ///
	star(* 0.1 ** 0.05 *** 0.01) ///
	stats(N, fmt(0) label("Observations")) ///
	collabels(none) ///	
	mlabels("Inside" "Outside") ///	
	title("Table D.2: Segments along All the Border where Geographic Characteristics Balance: `explanation'") ///	
	order(elevation elevation_2 slope slope_2 average_temp average_temp_2)  ///
	varlabels(elevation "Elevation" elevation_2 " " slope "Slope" slope_2 " " average_temp "Temperature" average_temp_2 " ") ///
	addnotes( ///
    "\scriptsize \textit{Notes:} The table corresponds to areas along the entire border where features balance. The unit of observation is 1x1 km grid cells. Robust standard errors for the difference in means between UFCo and non-UFCo observations are in parentheses, and Conley standard errors in brackets. We denote:  \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).") ///
	replace	

	eststo clear	
	
}