*******************************************************************************
* "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
* Esteban Méndez and Diana Van Patten
*
*******************************************************************************
*Table F.7: Human Capital Accumulation: Non-Migrants 1973-2011
version 16.1
clear all

set more off

*Path to the folder where dataset is located 
global dirdata "..."

*Path to the ado-file that implements the Conley Standard Errors (ols_spatial_HAC)
global dirado "..."

*Path to the final outputs (tables)
global dirout "..."

*Load the program that implements the Conley Standard Errors (ols_spatial_HAC)
run "$dirado/ols_spatial_HAC.ado" 

*Load dataset
use "$dirdata/Astua_Pirie_Ind_no_migrants.dta", clear

*Initialize the group of variables:

*Individual controls
local ind_controls age agesqrt female

*Latitude and longitude
local coordinates lat lon

*Geographic controls
local geographic elevation slope average_temp

*Year Fixed Effects
local year_fe y_1973 y_1984 y_2000 y_2011

*Outcome variables
foreach outcome in yrs_sch primary secondary {
	
display "`outcome'"	

*********************************************************************************************************************************************************************************************************************************************
* Table F.7: Human Capital Accumulation: Non-Migrants 1973-2011
*********************************************************************************************************************************************************************************************************************************************

*List of covariates
local covariates `coordinates' `geographic' `ind_controls' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo `covariates' if distance<5, vce(cluster census_block)

	*Store results
	estimates store m_`outcome'
	
	*Mean of the dependent variable
	sum `outcome' if distance<5
	scalar r_mean = r(mean)
	estadd scalar r_mean: m_`outcome'	
	
*Using Conley Standard Errors
	ols_spatial_HAC `outcome' UFCo `covariates' if distance<5, lat(lat) lon(lon) t(time) p(census_block) dist(2) lag(0)
	
	*Store results (Conley Standard Errors)
	scalar se_conley = _se[UFCo]

	local t = _b[UFCo]/_se[UFCo]
	local p =2*ttail(e(df_r),abs(`t'))

	matrix se_conley = (`=se_conley', ., ., ., ., ., ., ., ., ., ., ., ., .)
	mat colnames se_conley = UFCo . . . . . . . . . . . . .
	matrix se_conley_p = (`p', ., ., ., ., ., ., ., ., ., ., ., ., .)
	mat colnames se_conley_p = UFCo . . . . . . . . . . . . .	
	
	estadd matrix se_conley: m_`outcome'
	estadd matrix se_conley_p: m_`outcome'	
}

*Generate Table F.7 using previous results
esttab m_yrs_sch m_primary m_secondary using "$dirout/Table_F7.tex", cells(b(fmt(3)) se(par fmt(3) star) se_conley(par([ ]) fmt(3) star pvalue(se_conley_p)) ) ///
star(* 0.1 ** 0.05 *** 0.01) ///
stats(r2_a N N_clust r_mean, fmt(3 0 0 3) label("Adjusted \(R^{2}\)" "Observations" "Clusters" "Mean")) ///
keep(UFCo) ///
collabels(none) ///
mlabels("Years of schooling" "Primary" "Secondary") ///
title("Table F.7: Human Capital Accumulation: Non-Migrants 1973-2011") ///
addnotes("\textit{Notes:} Observations: 26,179; clusters: 206. The unit of observation is the individual. Robust standard errors, adjusted for clustering by census block, are in parentheses. Conley standard errors are in brackets. All regressions include geographic and individual controls, census fixed effects, and a linear polynomial in latitude and longitude.") ///
replace 