*******************************************************************************
* "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
* Esteban Méndez and Diana Van Patten
*
*******************************************************************************
*Table G.9: UFCo Effect using Luminosity Data
version 16.1
clear all

set more off

*Path to the folder where dataset is located 
global dirdata "..."

*Path to the ado-file that implements the Conley Standard Errors (ols_spatial_HAC)
global dirado "..."

*Path to the final outputs (tables)
global dirout "..."

*Load the program that implements the Conley Standard Errors (ols_spatial_HAC)
run "$dirado/ols_spatial_HAC.ado" 

*Load dataset
use "$dirdata/luminosity_data.dta", replace

foreach outcome in light capita growth light_transformation capita_transformation {
	
display "`outcome'"	

*Using Robust Standard Errors
reg `outcome' UFCo i.year if distance<5, r
local df = e(df_r)

	*Store results
	estimates store m_`outcome'

*Using Conley Standard Errors
if "`outcome'" == "light" |  "`outcome'" == "capita" | "`outcome'" == "light_transformation" | "`outcome'" == "capita_transformation" {  
ols_spatial_HAC `outcome' UFCo cons y1993-y2013 if distance<5, lat(lat) lon(lon) t(year) p(id) dist(2) lag(0)
}
if "`outcome'" == "growth" {  
ols_spatial_HAC `outcome' UFCo cons y1994 y1996-y2009 y2011-y2013 if distance<5, lat(lat) lon(lon) t(year) p(id) dist(2) lag(0)
}
	*Store results (Conley Standard Errors)
	scalar se_conley = _se[UFCo]
	local t = _b[UFCo]/_se[UFCo]
	local p =2*ttail(`df',abs(`t'))

	matrix r_se = (`=se_conley', ., ., ., ., ., ., ., ., ., ., ., ., .)
	mat colnames r_se = UFCo . . . . . . . . . . . . .
	matrix r_p = (`p', ., ., ., ., ., ., ., ., ., ., ., ., .)
	mat colnames r_p = UFCo . . . . . . . . . . . . .	
	
	estadd matrix r_se: m_`outcome'
	estadd matrix r_p: m_`outcome'	

}

*Generate Table G.9 using previous results
esttab m_light m_capita m_growth m_light_transformation m_capita_transformation using "$dirout/Table_G9.tex", cells(b(fmt(3)) se(par fmt(3) star) r_se(par([ ]) fmt(3) star pvalue(r_p)) ) ///
star(* 0.1 ** 0.05 *** 0.01) ///
stats(r2_a N, fmt(3 0) label("Adjusted \(R^{2}\)" "Observations")) ///
keep(UFCo) ///
collabels(none) ///
mlabels("ln Light" "ln Light/Pop" "Gr. Rate Light/Pop" "ln(.01+Light)" "ln(.01+Light/Pop)") ///
title("Table G.9: UFCo Effect using Luminosity Data") ///
addnotes("\scriptsize \textit{Notes:} The unit of observation is 1x1 km grid cells located within 5 km of UFCo boundary. Robust standard errors are in parentheses. Conley standard errors are in brackets. Regressions include year fixed effects. We denote: \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).") ///
replace