*******************************************************************************
* "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
* Esteban Méndez and Diana Van Patten
*
*******************************************************************************
*Table H.10: Negatively Selected Migrants to UFCo Regions: 1927 Population Census
version 16.1
clear all

set more off

*Path to the folder where dataset is located 
global dirdata "..."

*Path to the final outputs (tables)
global dirout "..."

*Import 1927 census database
use "$dirdata/Census_1927_dataset.dta", replace

*Sampling procedure is detailed in page 49 "El censo de población de 1927: creación de una base nominal computarizada."
*Declare survey design
svyset hh_id [pw = FEXPAND ], strata( ID_CANTON )

*Due to the extension of a Canton, the UFCo is better approximated with the intensive margin (i.e. UFCo_intensive variable)

*Compare migrants across regions
*Outcome variables
foreach outcome in property primary secondary literacy {
	
display "`outcome'"	

*Non-UFCo cantons
svy, subpop( if migration==1): reg `outcome' UFCo_intensive age agesqrt female lat_cant lon_cant

*Store results
estimates store m_`outcome'_non_UFCo

*Mean
svy, subpop( if migration==1): mean `outcome'
scalar r_mean = e(b)[1,1]
estadd scalar r_mean: m_`outcome'_non_UFCo

*Neighboring cantons:
svy, subpop( if migration==1 & nbr_canton==1): reg `outcome' UFCo_intensive age agesqrt female lat_cant lon_cant

*Store results
estimates store m_`outcome'_neig

*Mean
svy, subpop( if migration==1 & nbr_canton==1): mean `outcome'
scalar r_mean = e(b)[1,1]
estadd scalar r_mean: m_`outcome'_neig

}

*Generate Table H.10 - non-UFCo cantons
esttab m_property_non_UFCo m_primary_non_UFCo m_secondary_non_UFCo m_literacy_non_UFCo ///
using "$dirout/Table_H10_a.tex", cells(b(fmt(3)) se(par fmt(3) star)) ///
star(* 0.1 ** 0.05 *** 0.01) ///
stats(r2 N_sub r_mean, fmt(3 0 3) label("\(R^{2}\)" "Observations" "Mean")) ///
keep(UFCo_intensive) ///
collabels(none) ///
mlabels("Owning property" "Primary education" "Secondary education" "Literacy") ///
title("Table H.10: Negatively Selected Migrants to UFCo Regions: 1927 Population Census - non-UFCo cantons") ///
addnotes("\scriptsize \textit{Notes:} The unit of observation is the individual. Regressions are weighted using sample weights. Robust standard errors, adjusted for clustering by PSUs and  stratification at the canton level, in parentheses. UFCo corresponds to the fraction of canton's area that belonged to the UFCo landholdings. All regressions include individual controls (age, age squared, gender), and a linear polynomial in latitude and longitude. We denote: \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\)") ///
replace

*Generate Table H.10 - neighboring non-UFCo cantons
esttab m_property_neig m_primary_neig m_secondary_neig m_literacy_neig ///
using "$dirout/Table_H10_b.tex", cells(b(fmt(3)) se(par fmt(3) star)) ///
star(* 0.1 ** 0.05 *** 0.01) ///
stats(r2 N_sub r_mean, fmt(3 0 3) label("\(R^{2}\)" "Observations" "Mean")) ///
keep(UFCo_intensive) ///
collabels(none) ///
mlabels("Owning property" "Primary education" "Secondary education" "Literacy") ///
title("Table H.10: Negatively Selected Migrants to UFCo Regions: 1927 Population Census - neighboring non-UFCo cantons") ///
addnotes("\scriptsize \textit{Notes:} The unit of observation is the individual. Regressions are weighted using sample weights. Robust standard errors, adjusted for clustering by PSUs and  stratification at the canton level, in parentheses. UFCo corresponds to the fraction of canton's area that belonged to the UFCo landholdings. All regressions include individual controls (age, age squared, gender), and a linear polynomial in latitude and longitude. We denote: \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\)") ///
replace