*******************************************************************************
* "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
* Esteban Méndez and Diana Van Patten
*
*******************************************************************************
*Table J.13: Comparison of Government Spending per Capita across Municipalities
version 16.1
clear all

set more off

*Path to the folder where dataset is located 
global dirdata "..."

*Path to the final outputs (tables)
global dirout "..."

*Load dataset
use "$dirdata/municipal_spending_rural.dta"

*Column (1)
reg ln_spend_pc canton_UFCO, vce(cluster municipality)
*Store results
estimates store m_1

*Column (2)
reg ln_spend_pc canton_UFCO i.year, vce(cluster municipality)
*Store results
estimates store m_2

*Generate Table J.13 using previous results
esttab m_1 m_2 using "$dirout/Table_J13.tex", cells(b(fmt(3)) se(par fmt(3) star)) ///
star(* 0.1 ** 0.05 *** 0.01) ///
stats(r2_a N N_clust, fmt(3 0 0) label("Adjusted \(R^{2}\)" "Observations" "Clusters")) ///
keep(canton_UFCO) ///
varlabels(canton_UFCO "UFCo") ///
indicate("Year FE = *.year") ///
collabels(none) ///
eqlabels(" " " ") ///	
title("Table J.13: Comparison of Government Spending per Capita across Municipalities") ///
addnotes("\scriptsize \textit{Notes:} Observations: 690. Clusters: 50. The unit of observation is the municipality. Robust standard errors clustered by municipality, in parentheses. We denote: \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).") ///
replace