*******************************************************************************
* "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
* Esteban Méndez and Diana Van Patten
*
*******************************************************************************
*Table K.14: Average UFCo Effect-Comparison Between Households on the Pacific Coast and the Caribbean Coast
*Due to the sample size, it is preferable to estimate the Conley Standard Errors in MATLAB (code: Table_K14_Conley_Standard_Errors.m) 
version 16.1
clear all

set more off

*Path to the folder where dataset is located 
global dirdata "..."

*Path to the final outputs (tables)
global dirout "..."

*Load dataset
use "$dirdata/Census_HH.dta", replace

*Initialize the group of variables:

*Geographic controls
local geographic elevation slope average_temp

*Demographic controls
local hh_controls adult infant children

*Census Fixed Effects
local year_fe y_2000 y_2011 y_1984 y_1973

*Latitude and longitude
local coordinates lat lon 

*Outcome variables
foreach outcome in housing health education consumption poor ubn {
	
display "`outcome'"	
	
*********************************************************************************************************************************************************************************************************************************************
* Table K.14: Average UFCo Effect-Comparison Between Households on the Pacific Coast and the Caribbean Coast
*********************************************************************************************************************************************************************************************************************************************	

*List of covariates
local covariates `coordinates' `geographic' `hh_controls' `year_fe'

*Using Clustered Standard Errors at the Census Block Level
	reg `outcome' UFCo##Pacific `covariates' if distance<5, vce(cluster census_block)

	*Store results
	estimates store m_`outcome'

*Generate file to estimate Conley Standard Errors in MATLAB
	outsheet `outcome' UFCo_Pacific UFCo Pacific `covariates' census_block if distance<5 using "$dirout/Pacific_`outcome'_conley_input.csv", comma nolabel replace	
	
}

*Generate Table K.14 using previous results (except for Conley Standard Errors)
esttab m_housing m_health m_education m_consumption m_poor m_ubn using "$dirout/Table_K14.tex", cells(b(fmt(3)) se(par fmt(3) star)) ///
star(* 0.1 ** 0.05 *** 0.01) ///
stats(r2_a N N_clust, fmt(3 0 0) label("Adjusted \(R^{2}\)" "Observations" "Clusters")) ///
keep(1.UFCo#1.Pacific 1.UFCo 1.Pacific) ///
order(1.UFCo#1.Pacific 1.UFCo 1.Pacific) ///
varlabels(1.UFCo#1.Pacific "UFCoXPacific" 1.UFCo "UFCo" 1.Pacific "Pacific") ///
collabels(none) ///
mlabels("Housing" "Health" "Education" "Consumption" "Probability of being poor" "Total number of UBN") ///
title("Table K.14: Average UFCo Effect-Comparison Between Households on the Pacific Coast and the Caribbean Coast") ///
addnotes("\scriptsize \textit{Notes:}  UBN= Unsatisfied Basic Need. The unit of observation is the household. Robust standard errors, adjusted for clustering by census block, are in parentheses. All regressions include geographic controls (slope, elevation, temperature); demographic controls for the number of adults, children, and infants in the household; census fixed effects, and a linear polynomial in latitude and longitude. We denote: \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\).") ///
replace
