%*******************************************************************************
% "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
% Esteban Méndez and Diana Van Patten
%
%******************************************************************************
%Table 3: Outside Option in 1973 for UFCo Workers and Outcomes in 2000 and 2011 within the UFCo

%This code generates the Conley Standard Errors for Table 3. It uses 
%the files housing_wage.csv, health_wage.csv, education_wage.csv, consumption_wage.csv,
%poor_wage, and ubn_wage.csv, produced by "Table 3.do"
clear all

%Path to the folder where inputs from "Table 3.do" are located 
dirdata = '...';

%Path to the m-file that implements the Conley Standard Errors (regress_panel_spatial_HAC)
dirado = '...';

%Path to the final outputs
dirout = '...';

outcome    = linspace(1,6,6);

result.need  = ones(1,1);
result.coeff = ones(1,1);
result.se    = ones(1,1);
result.pval  = ones(1,1);

outcome_housing = ones(1,4);
outcome_health = ones(1,4)*2;
outcome_education = ones(1,4)*3;
outcome_consumption = ones(1,4)*4;
outcome_poor = ones(1,4)*5;
outcome_ubn = ones(1,4)*6;

count = 1;
for kk = 1:6

        if outcome(kk)==1
        FileName=['housing_wage.csv'];
        elseif outcome(kk)==2
        FileName=['health_wage.csv'];
        elseif outcome(kk)==3
        FileName=['education_wage.csv'];
        elseif outcome(kk)==4
        FileName=['consumption_wage.csv'];  
        elseif outcome(kk)==5
        FileName=['poor_wage.csv'];
        elseif outcome(kk)==6
        FileName=['ubn_wage.csv'];           
        end

        A = importdata(FileName);

        %Estimate Conley standard errors
        y = A.data(:,1);
        sz = size(A.data(:,2));
        X = [A.data(:,2:10)];
        loc  = A.data(:,3:4);
        year = ones(sz(1),1);
        panelvar  = A.data(:,11);
        locCutoff = 2;
        lagCutoff = 0;

        [output] = regress_panel_spatial_HAC(y, X, loc, year, panelvar, locCutoff, lagCutoff, 'yes');

        result.need(count,1)  = kk;
        result.coeff(count,1) = output.coeff(1,2);
        result.se(count,1)    = output.se(1,2);
        result.pval(count,1)  = output.p_val(1,2);
        
        if outcome(kk)==1
        outcome_housing_wage = [output.coeff(1,1),output.se(1,1), output.p_val(1,1)];
        elseif outcome(kk)==2
        outcome_health_wage = [output.coeff(1,1),output.se(1,1), output.p_val(1,1)];
        elseif outcome(kk)==3
        outcome_education_wage = [output.coeff(1,1),output.se(1,1), output.p_val(1,1)]; 
        elseif outcome(kk)==4
        outcome_consumption_wage = [output.coeff(1,1),output.se(1,1), output.p_val(1,1)]; 
        elseif outcome(kk)==5
        outcome_poor_wage = [output.coeff(1,1),output.se(1,1), output.p_val(1,1)]; 
        elseif outcome(kk)==6
        outcome_ubn_wage = [output.coeff(1,1),output.se(1,1), output.p_val(1,1)];         
        end

        count = count+1;

end

%Save output
cd(dirout)
writematrix(outcome_housing_wage, 'housing_wage_cse.csv')
writematrix(outcome_health_wage, 'health_wage_cse.csv')
writematrix(outcome_education_wage, 'education_wage_cse.csv')
writematrix(outcome_consumption_wage, 'consumption_wage_cse.csv')
writematrix(outcome_poor_wage, 'poor_wage_cse.csv')
writematrix(outcome_ubn_wage, 'ubn_wage_cse.csv')