%*******************************************************************************
% "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
% Esteban Méndez and Diana Van Patten
%
%******************************************************************************
%Table 4: IV Strategy: Outside Options in 1973 for UFCo Workers and Outcomes in 2000 and 2011 within the UFCo

%This code generates the Conley Standard Errors for Table 4. It uses 
%the files housing_outside_option.csv, health_outside_option.csv, 
%education_outside_option.csv, consumption_outside_option.csv, poor_outside_option.csv, and
%ubn_outside_option.csv, produced by "Table 4.do"
clear all

%Path to the folder where inputs from "Table 4.do" are located 
dirdata = '...';

%Path to the m-file that implements the Conley Standard Errors (regress_panel_spatial_HAC)
dirado = '...';

%Path to the final outputs
dirout = '...';

outcome    = linspace(1,6,6);

result.need  = ones(1,1);
result.coeff = ones(1,1);
result.se    = ones(1,1);
result.pval  = ones(1,1);

outcome_housing = ones(1,4);
outcome_health = ones(1,4)*2;
outcome_education = ones(1,4)*3;
outcome_consumption = ones(1,4)*4;
outcome_poor = ones(1,4)*5;
outcome_ubn = ones(1,4)*6;

count = 1;
for kk = 1:6

        if outcome(kk)==1
        FileName=['housing_outside_option.csv'];
        elseif outcome(kk)==2
        FileName=['health_outside_option.csv'];
        elseif outcome(kk)==3
        FileName=['education_outside_option.csv'];
        elseif outcome(kk)==4
        FileName=['consumption_outside_option.csv'];  
        elseif outcome(kk)==5
        FileName=['poor_outside_option.csv'];
        elseif outcome(kk)==6
        FileName=['ubn_outside_option.csv'];           
        end

        A = importdata(FileName);
        
        %Estimate Conley standard errors
        y = A.data(:,1);
        sz = size(A.data(:,2));
        X = [A.data(:,2:10)];
        loc  = A.data(:,3:4);
        year = ones(sz(1),1);
        panelvar  = A.data(:,11);
        locCutoff = 2;
        lagCutoff = 0;

        [output] = regress_panel_spatial_HAC(y, X, loc, year, panelvar, locCutoff, lagCutoff, 'yes');

        result.need(count,1)  = kk;
        result.coeff(count,1) = output.coeff(1,2);
        result.se(count,1)    = output.se(1,2);
        result.pval(count,1)  = output.p_val(1,2);
        
        if outcome(kk)==1
        outcome_housing_outside = [output.coeff(1,1),output.se(1,1), output.p_val(1,1)];
        elseif outcome(kk)==2
        outcome_health_outside = [output.coeff(1,1),output.se(1,1), output.p_val(1,1)];
        elseif outcome(kk)==3
        outcome_education_outside = [output.coeff(1,1),output.se(1,1), output.p_val(1,1)]; 
        elseif outcome(kk)==4
        outcome_consumption_outside = [output.coeff(1,1),output.se(1,1), output.p_val(1,1)]; 
        elseif outcome(kk)==5
        outcome_poor_outside = [output.coeff(1,1),output.se(1,1), output.p_val(1,1)]; 
        elseif outcome(kk)==6
        outcome_ubn_outside = [output.coeff(1,1),output.se(1,1), output.p_val(1,1)];         
        end            
        
        count = count+1;

end

%Save output
cd(dirout)
writematrix(outcome_housing_outside, 'housing_outside_option_cse.csv')
writematrix(outcome_health_outside, 'health_outside_option_cse.csv')
writematrix(outcome_education_outside, 'education_outside_option_cse.csv')
writematrix(outcome_consumption_outside, 'consumption_outside_option_cse.csv')
writematrix(outcome_poor_outside, 'poor_outside_option_cse.csv')
writematrix(outcome_ubn_outside, 'ubn_outside_option_cse.csv')
