%*******************************************************************************
% "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
% Esteban Méndez and Diana Van Patten
%
%******************************************************************************
%Table K.14: Average UFCo Effect-Comparison Between Households on the Pacific Coast and the Caribbean Coast

%This code generates the Conley Standard Errors for Table 4. It uses 
%the files Pacific_housing_conley_input.csv, Pacific_health_conley_input.csv, 
%Pacific_education_conley_input.csv, Pacific_consumption_conley_input.csv, 
%Pacific_poor_conley_input.csv, and Pacific_ubn_conley_input.csv, produced by "Table K14.do"
clear all

%Path to the folder where inputs from "Table K14.do" are located 
dirdata = '...';

%Path to the m-file that implements the Conley Standard Errors (regress_panel_spatial_HAC)
dirado = '...';

%Path to the final outputs
dirout = '...';
 
outcome    = linspace(1,6,6);

result.need  = ones(1,1);
result.coeff = ones(1,1);
result.se    = ones(1,1);
result.pval  = ones(1,1);

outcome_housing = ones(1,4);
outcome_health = ones(1,4)*2;
outcome_education = ones(1,4)*3;
outcome_consumption = ones(1,4)*4;
outcome_poor = ones(1,4)*5;
outcome_ubn = ones(1,4)*6;

count = 1;
for kk = 1:6

        if outcome(kk)==1
        FileName=['Pacific_housing_conley_input.csv'];
        elseif outcome(kk)==2
        FileName=['Pacific_health_conley_input.csv'];
        elseif outcome(kk)==3
        FileName=['Pacific_education_conley_input.csv'];
        elseif outcome(kk)==4
        FileName=['Pacific_consumption_conley_input.csv'];  
        elseif outcome(kk)==5
        FileName=['Pacific_poor_conley_input.csv'];
        elseif outcome(kk)==6
        FileName=['Pacific_ubn_conley_input.csv'];           
        end

        %Estimate Conley standard errors
        A = importdata(FileName);
        y = A.data(:,1);
        sz = size(A.data(:,2));
        X = [A.data(:,2:16)];
        loc  = A.data(:,5:6);
        year = ones(sz(1),1);
        panelvar  = A.data(:,17);
        locCutoff = 2;
        lagCutoff = 0;
 
        [output] = regress_panel_spatial_HAC(y, X, loc, year, panelvar, locCutoff, lagCutoff, 'yes');

        result.need(count,1)  = kk;
        result.coeff(count,1) = output.coeff(1,2);
        result.se(count,1)    = output.se(1,2);
        result.pval(count,1)  = output.p_val(1,2);
        
        if outcome(kk)==1
        outcome_housing = [output.coeff(1,1),output.se(1,1), output.p_val(1,1)];
        elseif outcome(kk)==2
        outcome_health = [output.coeff(1,1),output.se(1,1), output.p_val(1,1)];
        elseif outcome(kk)==3
        outcome_education = [output.coeff(1,1),output.se(1,1), output.p_val(1,1)]; 
        elseif outcome(kk)==4
        outcome_consumption = [output.coeff(1,1),output.se(1,1), output.p_val(1,1)]; 
        elseif outcome(kk)==5
        outcome_poor = [output.coeff(1,1),output.se(1,1), output.p_val(1,1)]; 
        elseif outcome(kk)==6
        outcome_ubn = [output.coeff(1,1),output.se(1,1), output.p_val(1,1)];         
        end

        count = count+1;

end

%Save output
cd(dirout)
writematrix(outcome_housing,'Pacific_housing_cse.csv') 
writematrix(outcome_health,'Pacific_health_cse.csv')
writematrix(outcome_education,'Pacific_education_cse.csv')
writematrix(outcome_consumption,'Pacific_consumption_cse.csv')
writematrix(outcome_poor,'Pacific_poor_cse.csv')
writematrix(outcome_ubn,'Pacific_ubn_cse.csv')
