*This do file implement the Imbens-Kolesar calculations
*The code is based on code used in A. Colin Cameron & Douglas L. Miller, 2015. 
*"A Practitioner's Guide to Cluster-Robust Inference," Journal of Human Resources, 
*University of Wisconsin Press, vol. 50(2), pages 317-372.

cap prog drop estimate_the_SE_IK 
prog def estimate_the_SE_IK 
syntax  , [outcome(string) covariates(string) distance(real 6)] 

local lhs = "`outcome'"
capture confirm variable UFCo //Identify if variable UFCo exists
*If it exists in the dataset, it is the focal independent variable
if _rc == 0 {
local key_rhs = "UFCo" 
local rhs = "`UFCo' `covariates'" 
}
capture confirm variable control_region //Identify if variable control_region exists
*If it exists in the dataset, it is the focal independent variable
if _rc == 0 {
local key_rhs = "control_region" 
local rhs = "`control_region' `covariates'" 
}  

local command = "reg `lhs' `rhs'  , cluster(pseudo_cluster) " 

local beta_hypothesis = 0 

/* preserve the data */
preserve 

/*Drop observations that will not be used*/
capture confirm variable distance //Identify if variable distance exists
*If it exists in the dataset, drop observations above the threshold
if _rc == 0 {
drop if distance>`distance'
}

/* generate pseudo-cluster-ids for later */
gen pseudo_cluster = census_block

/* estimate the models */
capture confirm variable UFCo //Identify if variable UFCo exists
*If it exists in the dataset, it is the focal independent variable
if _rc == 0 {
reg `outcome' UFCo `covariates', robust 
local b = _b[UFCo] 
local se_rob = _se[UFCo] 
local K = e(rank) 
local numobs = e(N) 
}

capture confirm variable control_region //Identify if variable control_region exists
*If it exists in the dataset, it is the focal independent variable
if _rc == 0 {
reg `outcome' control_region `covariates', robust 
local b = _b[control_region] 
local se_rob = _se[control_region] 
local K = e(rank) 
local numobs = e(N) 
}

tempname betavec v_naive 
matrix `betavec' = e(b)

/* generate residuals.  Also, generate "restricted, impose the null hypothesis" residuals */
predict yhat , xb 
predict resid , resid 

capture confirm variable UFCo //Identify if variable UFCo exists
*If it exists in the dataset, it is the focal independent variable
if _rc == 0 {
reg `outcome' UFCo `covariates', cluster(pseudo_cluster) 
local se_clu = _se[UFCo] 
}

capture confirm variable control_region //Identify if variable control_region exists
*If it exists in the dataset, it is the focal independent variable
if _rc == 0 {
reg `outcome' control_region `covariates', cluster(pseudo_cluster) 
local se_clu = _se[control_region] 
}

gen one = 1 
sort pseudo_cluster 
gen obsnum = _n 

/* get the CR2, CR3 standard errors adjustments.  Also get I-K degrees of freedom, and CSS effective number of clusters */
CR23_IK_CSS , betavec(`betavec') lhs(`lhs') rhs(`rhs') key_rhs(`key_rhs')

foreach r in se_CR2 se_CR3 dof_CR2_IK dof_CSS { 
	local `r' = r(`r') 
} 

*Display Imbens-Kolesar Degrees of Freedom  
display dof_CR2_IK

*Display CR2 standard erros
display se_CR2

*Calculate and display p-value
scalar p_CR2_Tik = 2 * ttail(dof_CR2_IK,(abs(`b' - 0) / se_CR2)) 
display p_CR2_Tik

estadd scalar dof_CR2_IK=r(dof_CR2_IK)
estadd scalar se_CR2=r(se_CR2)
eststo: estadd scalar p_CR2_Tik=p_CR2_Tik

restore

end 
