%*******************************************************************************
% "Multinationals, Monopsony, and Local Development: Evidence from the United Fruit Company"
% Esteban Méndez and Diana Van Patten
%
%******************************************************************************
%Figure 3: Average UFCo Effect Considering the Entire Concession's Border
%Figure 4: Dynamic UFCo Effect Considering the Entire Concession's Border

%This is the second code to obtain Figures 3 and 4. 
%Due to the sample size, it is preferable to estimate the Conley Standard Errors in MATLAB. Therefore, the code to generate Figure 3 and 4 is split.
%Part 1 estimates for each outcome a regression at a distance of 250 m up to 20 km from the UFCo border. The code also obtains the clustered standard errors, and the data to estimate the Conley Standard Errors in MATLAB.
%Part 2 estimates the Conley Standard Errors (in MATLAB).
%Part 3 imports and merges the outputs from MATLAB and Stata, and generates the plots.
%The instructions to generate Figure 3 and 4 are:
%1) Run "Figures 3 and 4 part 1.do" in Stata
%2) Run "Figures_3_and_4_part 2.m" in MATLAB
%3) Run "Figures 3 and 4 part 2.do" in Stata

%This code uses the files "housing_conley_input_", "health_conley_input_", 
%"education_conley_input_", "consumption_conley_input_", "ubn_conley_input_", 
%"poor_conley_input_", produced by "Figures 3 and 4 part 1.do"

%The code produces the files "outcome_housing.csv", "outcome_health.csv",
%"outcome_education.csv", "outcome_consumption.csv", "outcome_poor.csv", 
%"outcome_ubn.csv"
clear all

%Path to the folder where dataset is located 
dirdata = '...';

%Path to the m-file that implements the Conley Standard Errors (regress_panel_spatial_HAC)
dirado = '...';

%Path to the final outputs
dirout = '...';

%Add folders to search path
addpath(dirdata)
addpath(dirado)

%
kilometers = linspace(5,20,61)'*100; 
kilometers = floor(kilometers)/100;
outcome    = linspace(1,6,6);
BaseName={'housing_conley_input_', 'health_conley_input_', ...
          'education_conley_input_', 'consumption_conley_input_', ...
          'poor_conley_input_', 'ubn_conley_input_'};

result.need  = ones(6*61,1);
result.dist  = ones(6*61,1);
result.coeff = ones(6*61,1);
result.se    = ones(6*61,1);
result.pval  = ones(6*61,1);

outcome_housing = ones(61,6);
outcome_health = ones(61,6)*2;
outcome_education = ones(61,6)*3;
outcome_consumption = ones(61,6)*4;
outcome_poor = ones(61,6)*5;
outcome_ubn = ones(61,6)*6;

count = 1;
for kk = 1:6
    for i = 1:2 %61 regressions
        for k=kilometers(i) %distance

        if outcome(kk)==1
        FileName=['housing_conley_input_',num2str(k), '.csv'];
        elseif outcome(kk)==2
        FileName=['health_conley_input_',num2str(k), '.csv'];
        elseif outcome(kk)==3
        FileName=['education_conley_input_',num2str(k), '.csv'];
        elseif outcome(kk)==4
        FileName=['consumption_conley_input_',num2str(k), '.csv'];
        elseif outcome(kk)==5
        FileName=['poor_conley_input_',num2str(k), '.csv'];
        elseif outcome(kk)==6
        FileName=['ubn_conley_input_',num2str(k), '.csv'];
        end

        A = importdata(FileName);
        y = A.data(:,1);
        sz = size(A.data(:,2));
        X = [A.data(:,2:14)];
        loc  = A.data(:,3:4);
        year = ones(sz(1),1);
        panelvar  = A.data(:,15);
        locCutoff = 2;
        lagCutoff = 0;

        [output] = regress_panel_spatial_HAC(y, X, loc, year, panelvar, locCutoff, lagCutoff, 'yes');

        result.need(count,1)  = kk;
        result.dist(count,1)  = kilometers(i);
        result.coeff(count,1) = output.coeff(1,1);
        result.se(count,1)    = output.se(1,1);
        result.pval(count,1)  = output.p_val(1,1);
        
        if outcome(kk)==1
        outcome_housing(i,2:6) = [kilometers(i), output.coeff(1,1),output.se(1,1), output.p_val(1,1), mean(A.data(:,16))];
        elseif outcome(kk)==2
        outcome_health(i,2:6) = [kilometers(i), output.coeff(1,1),output.se(1,1), output.p_val(1,1), mean(A.data(:,16))];
        elseif outcome(kk)==3
        outcome_education(i,2:6) = [kilometers(i), output.coeff(1,1),output.se(1,1), output.p_val(1,1), mean(A.data(:,16))];
        elseif outcome(kk)==4
        outcome_consumption(i,2:6)= [kilometers(i), output.coeff(1,1),output.se(1,1), output.p_val(1,1), mean(A.data(:,16))];
        elseif outcome(kk)==5
        outcome_poor(i,2:6)= [kilometers(i), output.coeff(1,1),output.se(1,1),output.p_val(1,1), mean(A.data(:,16))];
        elseif outcome(kk)==6
        outcome_ubn(i,2:6)= [kilometers(i), output.coeff(1,1),output.se(1,1),output.p_val(1,1), mean(A.data(:,16))];
        end

        count = count+1;
        
        end
    end
end

%Save output
cd(dirout)
writematrix(outcome_housing,'outcome_housing.csv') 
writematrix(outcome_health,'outcome_health.csv')
writematrix(outcome_education,'outcome_education.csv')
writematrix(outcome_consumption,'outcome_consumption.csv')
writematrix(outcome_poor,'outcome_poor.csv')
writematrix(outcome_ubn,'outcome_ubn.csv')